package org.dasein.cloud.jclouds.atmos;

import org.apache.log4j.Logger;
import org.dasein.cloud.AbstractCloud;
import org.dasein.cloud.CloudException;
import org.dasein.cloud.ProviderContext;
import org.dasein.cloud.services.dc.DataCenterServices;
import org.dasein.cloud.services.storage.StorageServices;
import org.jclouds.blobstore.BlobStoreContext;
import org.jclouds.blobstore.BlobStoreContextFactory;

public class Atmos extends AbstractCloud {
    static private final Logger logger = Logger.getLogger(Atmos.class);
    
    public Atmos() { }

    @Override
    public String getCloudName() {
        String cloud = getContext().getCloudName();
        
        if( cloud != null ) {
            return cloud;
        }
        return "Atmos Online";
    }

    public BlobStoreContext getAtmosContext() throws CloudException {
        logger.debug("enter - getAtmosContext()");
        try {
            ProviderContext ctx = getContext();
            String account = new String(ctx.getAccessPublic());
            String key = new String(ctx.getAccessPrivate());
            
            String userId = account + "/" + ctx.getAccountNumber();
                
            return (new BlobStoreContextFactory()).createContext("synaptic", userId, key);
            //return AtmosStorageContextFactory.createContext(new URI(ctx.getEndpoint()), userId, key, new Log4JLoggingModule(), new ExecutorServiceModule(sameThreadExecutor(), sameThreadExecutor()));
        }
        finally {
            logger.debug("exit - getAtmosContext()");
        }
    }
    
    @Override
    public DataCenterServices getDataCenterServices() {
        return new DataCenters(this);
    }

    @Override
    public String getProviderName() {
        String provider = getContext().getProviderName();
        
        if( provider != null ) {
            return provider;
        }
        return "EMC";
    }

    @Override
    public StorageServices getStorageServices() {
        return new BlobStore(this);
    }
}
